RevealCallback typedef
RevealCallback =
void Function()
Callback invoked when the scratch area is fully revealed.
This is called after the widget detects that the scratched percentage meets or exceeds ScratchCard.revealThreshold.
Implementation
typedef RevealCallback = void Function();